netapp_ontap.models.qtree_statistics_raw API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.qtree_statistics_raw`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class QtreeStatisticsRawSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the QtreeStatisticsRaw object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `iops_raw GET`

    The iops_raw field of the qtree_statistics_raw.

  `status GET`

    Any errors associated with the sample. For example, if the aggregation of data over multiple nodes fails then any of the partial errors might be returned, "ok" on success, or "error" on any internal uncategorized failure. Whenever a sample collection is missed but done at a later time, it is back filled with the next closest collection and tagged with "backfilled_data". "inconsistent_delta_time" is encountered when the time between two collections is not the same for all nodes. Therefore, the aggregated value might be over or under inflated. "negative_delta" is returned when an expected monotonically increasing value has decreased in value. "inconsistent_old_data" is returned when one or more nodes does not have the latest data.

    Valid choices:

    - ok
    - error
    - partial_no_data
    - partial_no_uuid
    - partial_no_response
    - partial_other_error
    - negative_delta
    - backfilled_data
    - inconsistent_delta_time
    - inconsistent_old_data
  `throughput_raw GET`

    The throughput_raw field of the qtree_statistics_raw.

  `timestamp GET`

    The timestamp of the performance data.

    Example: 2017-01-25T11:20:13.000+0000